pub struct DiscoveryService { /* private fields */ }Implementations
Sourceimpl DiscoveryService
impl DiscoveryService
pub fn new(api_url: &str, dds_url: &str, client_id: &str) -> Self
Sourcepub async fn list_domains(
&self,
org: &str,
domain_server_id: Option<&str>,
) -> Result<ListDomainsResponse, DomainError>
pub async fn list_domains( &self, org: &str, domain_server_id: Option<&str>, ) -> Result<ListDomainsResponse, DomainError>
List domains with domain server without issue token
- org: (required) The organization to list domains from:
- “own”: returns domains in your own organization.
- a UUID: returns domains in that specific organization.
- “all”: returns domains across all organizations. Otherwise, ‘domain_server_id’ is required and the domain server must belong to your org. Not available for app tokens.
- domain_server_id: (optional) UUID of the domain server to filter domains. Ignored if a portal filter is active.
Access control
- App tokens can only see domains where the app is on the domain’s app allowlist (or the domain has no app allowlist).
- User tokens can see all domains in their own org. When requesting domains outside their org, they can only see domains where their org is on the domain’s user-org allowlist (or the domain has no user-org allowlist).
pub async fn sign_in_with_auki_account( &mut self, email: &str, password: &str, remember_password: bool, ) -> Result<String, DomainError>
pub async fn sign_in_as_auki_app( &mut self, app_key: &str, app_secret: &str, ) -> Result<String, DomainError>
pub fn with_oidc_access_token(&self, oidc_access_token: &str) -> Self
pub async fn auth_domain( &self, domain_id: &str, ) -> Result<DomainWithToken, DomainError>
pub async fn create_domain( &self, name: &str, domain_server_id: Option<String>, domain_server_url: Option<String>, redirect_url: Option<String>, ) -> Result<DomainWithToken, DomainError>
Sourcepub async fn list_domains_by_portal(
&self,
portal_id: Option<&str>,
portal_short_id: Option<&str>,
org: &str,
) -> Result<ListDomainsResponse, DomainError>
pub async fn list_domains_by_portal( &self, portal_id: Option<&str>, portal_short_id: Option<&str>, org: &str, ) -> Result<ListDomainsResponse, DomainError>
List domains by portal, portal_id or portal_short_id is required
If org is not provided, it will list domains for the current authorized organization
If org is provided, it will list domains for the specified organization
Set org to all to list domains for all organizations